==> apigateway-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/ProxyResourceProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:27:21.935Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ProxyResourceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigateway.ProxyResourceOptions {

    /**
     * The parent resource of this resource.
     * 
     * You can either pass another
     * `Resource` object or a `RestApi` object here.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IResource getParent();

    /**
     * @return a {@link Builder} of {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.services.apigateway.IResource parent;
        private java.lang.Boolean anyMethod;
        private software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions;
        private software.amazon.awscdk.services.apigateway.Integration defaultIntegration;
        private software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions;

        /**
         * Sets the value of Parent
         * @param parent The parent resource of this resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder parent(software.amazon.awscdk.services.apigateway.IResource parent) {
            this.parent = parent;
            return this;
        }

        /**
         * Sets the value of AnyMethod
         * @param anyMethod Adds an "ANY" method to this resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anyMethod(java.lang.Boolean anyMethod) {
            this.anyMethod = anyMethod;
            return this;
        }

        /**
         * Sets the value of DefaultCorsPreflightOptions
         * @param defaultCorsPreflightOptions Adds a CORS preflight OPTIONS method to this resource and all child resources.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultCorsPreflightOptions(software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions) {
            this.defaultCorsPreflightOptions = defaultCorsPreflightOptions;
            return this;
        }

        /**
         * Sets the value of DefaultIntegration
         * @param defaultIntegration An integration to use as a default for all methods created within this API unless an integration is specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultIntegration(software.amazon.awscdk.services.apigateway.Integration defaultIntegration) {
            this.defaultIntegration = defaultIntegration;
            return this;
        }

        /**
         * Sets the value of DefaultMethodOptions
         * @param defaultMethodOptions Method options to use as a default for all methods created within this API unless custom options are specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultMethodOptions(software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions) {
            this.defaultMethodOptions = defaultMethodOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProxyResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public ProxyResourceProps build() {
            return new Jsii$Proxy(parent, anyMethod, defaultCorsPreflightOptions, defaultIntegration, defaultMethodOptions);
        }
    }

    /**
     * An implementation for {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProxyResourceProps {
        private final software.amazon.awscdk.services.apigateway.IResource parent;
        private final java.lang.Boolean anyMethod;
        private final software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions;
        private final software.amazon.awscdk.services.apigateway.Integration defaultIntegration;
        private final software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.parent = this.jsiiGet("parent", software.amazon.awscdk.services.apigateway.IResource.class);
            this.anyMethod = this.jsiiGet("anyMethod", java.lang.Boolean.class);
            this.defaultCorsPreflightOptions = this.jsiiGet("defaultCorsPreflightOptions", software.amazon.awscdk.services.apigateway.CorsOptions.class);
            this.defaultIntegration = this.jsiiGet("defaultIntegration", software.amazon.awscdk.services.apigateway.Integration.class);
            this.defaultMethodOptions = this.jsiiGet("defaultMethodOptions", software.amazon.awscdk.services.apigateway.MethodOptions.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(software.amazon.awscdk.services.apigateway.IResource parent, java.lang.Boolean anyMethod, software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions, software.amazon.awscdk.services.apigateway.Integration defaultIntegration, software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.parent = java.util.Objects.requireNonNull(parent, "parent is required");
            this.anyMethod = anyMethod;
            this.defaultCorsPreflightOptions = defaultCorsPreflightOptions;
            this.defaultIntegration = defaultIntegration;
            this.defaultMethodOptions = defaultMethodOptions;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IResource getParent() {
            return this.parent;
        }

        @Override
        public java.lang.Boolean getAnyMethod() {
            return this.anyMethod;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.CorsOptions getDefaultCorsPreflightOptions() {
            return this.defaultCorsPreflightOptions;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration() {
            return this.defaultIntegration;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions() {
            return this.defaultMethodOptions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("parent", om.valueToTree(this.getParent()));
            if (this.getAnyMethod() != null) {
                obj.set("anyMethod", om.valueToTree(this.getAnyMethod()));
            }
            if (this.getDefaultCorsPreflightOptions() != null) {
                obj.set("defaultCorsPreflightOptions", om.valueToTree(this.getDefaultCorsPreflightOptions()));
            }
            if (this.getDefaultIntegration() != null) {
                obj.set("defaultIntegration", om.valueToTree(this.getDefaultIntegration()));
            }
            if (this.getDefaultMethodOptions() != null) {
                obj.set("defaultMethodOptions", om.valueToTree(this.getDefaultMethodOptions()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProxyResourceProps.Jsii$Proxy that = (ProxyResourceProps.Jsii$Proxy) o;

            if (!parent.equals(that.parent)) return false;
            if (this.anyMethod != null ? !this.anyMethod.equals(that.anyMethod) : that.anyMethod != null) return false;
            if (this.defaultCorsPreflightOptions != null ? !this.defaultCorsPreflightOptions.equals(that.defaultCorsPreflightOptions) : that.defaultCorsPreflightOptions != null) return false;
            if (this.defaultIntegration != null ? !this.defaultIntegration.equals(that.defaultIntegration) : that.defaultIntegration != null) return false;
            return this.defaultMethodOptions != null ? this.defaultMethodOptions.equals(that.defaultMethodOptions) : that.defaultMethodOptions == null;
        }

        @Override
        public int hashCode() {
            int result = this.parent.hashCode();
            result = 31 * result + (this.anyMethod != null ? this.anyMethod.hashCode() : 0);
            result = 31 * result + (this.defaultCorsPreflightOptions != null ? this.defaultCorsPreflightOptions.hashCode() : 0);
            result = 31 * result + (this.defaultIntegration != null ? this.defaultIntegration.hashCode() : 0);
            result = 31 * result + (this.defaultMethodOptions != null ? this.defaultMethodOptions.hashCode() : 0);
            return result;
        }
    }
}

==> apigateway-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/ProxyResourceProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:51.611Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.ProxyResourceProps")
@software.amazon.jsii.Jsii.Proxy(ProxyResourceProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ProxyResourceProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.apigateway.ProxyResourceOptions {

    /**
     * The parent resource of this resource.
     * 
     * You can either pass another
     * `Resource` object or a `RestApi` object here.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    software.amazon.awscdk.services.apigateway.IResource getParent();

    /**
     * @return a {@link Builder} of {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private software.amazon.awscdk.services.apigateway.IResource parent;
        private java.lang.Boolean anyMethod;
        private software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions;
        private software.amazon.awscdk.services.apigateway.Integration defaultIntegration;
        private software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions;

        /**
         * Sets the value of Parent
         * @param parent The parent resource of this resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder parent(software.amazon.awscdk.services.apigateway.IResource parent) {
            this.parent = parent;
            return this;
        }

        /**
         * Sets the value of AnyMethod
         * @param anyMethod Adds an "ANY" method to this resource.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder anyMethod(java.lang.Boolean anyMethod) {
            this.anyMethod = anyMethod;
            return this;
        }

        /**
         * Sets the value of DefaultCorsPreflightOptions
         * @param defaultCorsPreflightOptions Adds a CORS preflight OPTIONS method to this resource and all child resources.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultCorsPreflightOptions(software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions) {
            this.defaultCorsPreflightOptions = defaultCorsPreflightOptions;
            return this;
        }

        /**
         * Sets the value of DefaultIntegration
         * @param defaultIntegration An integration to use as a default for all methods created within this API unless an integration is specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultIntegration(software.amazon.awscdk.services.apigateway.Integration defaultIntegration) {
            this.defaultIntegration = defaultIntegration;
            return this;
        }

        /**
         * Sets the value of DefaultMethodOptions
         * @param defaultMethodOptions Method options to use as a default for all methods created within this API unless custom options are specified.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultMethodOptions(software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions) {
            this.defaultMethodOptions = defaultMethodOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ProxyResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public ProxyResourceProps build() {
            return new Jsii$Proxy(parent, anyMethod, defaultCorsPreflightOptions, defaultIntegration, defaultMethodOptions);
        }
    }

    /**
     * An implementation for {@link ProxyResourceProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ProxyResourceProps {
        private final software.amazon.awscdk.services.apigateway.IResource parent;
        private final java.lang.Boolean anyMethod;
        private final software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions;
        private final software.amazon.awscdk.services.apigateway.Integration defaultIntegration;
        private final software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.parent = this.jsiiGet("parent", software.amazon.awscdk.services.apigateway.IResource.class);
            this.anyMethod = this.jsiiGet("anyMethod", java.lang.Boolean.class);
            this.defaultCorsPreflightOptions = this.jsiiGet("defaultCorsPreflightOptions", software.amazon.awscdk.services.apigateway.CorsOptions.class);
            this.defaultIntegration = this.jsiiGet("defaultIntegration", software.amazon.awscdk.services.apigateway.Integration.class);
            this.defaultMethodOptions = this.jsiiGet("defaultMethodOptions", software.amazon.awscdk.services.apigateway.MethodOptions.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.apigateway.IResource parent, final java.lang.Boolean anyMethod, final software.amazon.awscdk.services.apigateway.CorsOptions defaultCorsPreflightOptions, final software.amazon.awscdk.services.apigateway.Integration defaultIntegration, final software.amazon.awscdk.services.apigateway.MethodOptions defaultMethodOptions) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.parent = java.util.Objects.requireNonNull(parent, "parent is required");
            this.anyMethod = anyMethod;
            this.defaultCorsPreflightOptions = defaultCorsPreflightOptions;
            this.defaultIntegration = defaultIntegration;
            this.defaultMethodOptions = defaultMethodOptions;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.IResource getParent() {
            return this.parent;
        }

        @Override
        public java.lang.Boolean getAnyMethod() {
            return this.anyMethod;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.CorsOptions getDefaultCorsPreflightOptions() {
            return this.defaultCorsPreflightOptions;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.Integration getDefaultIntegration() {
            return this.defaultIntegration;
        }

        @Override
        public software.amazon.awscdk.services.apigateway.MethodOptions getDefaultMethodOptions() {
            return this.defaultMethodOptions;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("parent", om.valueToTree(this.getParent()));
            if (this.getAnyMethod() != null) {
                data.set("anyMethod", om.valueToTree(this.getAnyMethod()));
            }
            if (this.getDefaultCorsPreflightOptions() != null) {
                data.set("defaultCorsPreflightOptions", om.valueToTree(this.getDefaultCorsPreflightOptions()));
            }
            if (this.getDefaultIntegration() != null) {
                data.set("defaultIntegration", om.valueToTree(this.getDefaultIntegration()));
            }
            if (this.getDefaultMethodOptions() != null) {
                data.set("defaultMethodOptions", om.valueToTree(this.getDefaultMethodOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-apigateway.ProxyResourceProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ProxyResourceProps.Jsii$Proxy that = (ProxyResourceProps.Jsii$Proxy) o;

            if (!parent.equals(that.parent)) return false;
            if (this.anyMethod != null ? !this.anyMethod.equals(that.anyMethod) : that.anyMethod != null) return false;
            if (this.defaultCorsPreflightOptions != null ? !this.defaultCorsPreflightOptions.equals(that.defaultCorsPreflightOptions) : that.defaultCorsPreflightOptions != null) return false;
            if (this.defaultIntegration != null ? !this.defaultIntegration.equals(that.defaultIntegration) : that.defaultIntegration != null) return false;
            return this.defaultMethodOptions != null ? this.defaultMethodOptions.equals(that.defaultMethodOptions) : that.defaultMethodOptions == null;
        }

        @Override
        public int hashCode() {
            int result = this.parent.hashCode();
            result = 31 * result + (this.anyMethod != null ? this.anyMethod.hashCode() : 0);
            result = 31 * result + (this.defaultCorsPreflightOptions != null ? this.defaultCorsPreflightOptions.hashCode() : 0);
            result = 31 * result + (this.defaultIntegration != null ? this.defaultIntegration.hashCode() : 0);
            result = 31 * result + (this.defaultMethodOptions != null ? this.defaultMethodOptions.hashCode() : 0);
            return result;
        }
    }
}
